==> ejc-salary-api-3.0.0-20241016.072905-29-sources.jar: com/ejianc/business/salary/vo/SourceDetailVO.java <==
package com.ejianc.business.salary.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 薪资来源
 * 
 * @author generator
 * 
 */
public class SourceDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Date month; // 月份
    private Long orgId; // 单位id
    private String orgName; // 单位名称
    private String orgCode; // 单位编码
    private Long sbcdOrgId; // 社保承担单位id
    private String sbcdOrgName; // 社保承担单位名称
    private String sbcdOrgCode; // 社保承担单位编码

    private BigDecimal unWriteOffMny; // 截止当前未核销金额
    private BigDecimal writeOffMny; // 本次核销金额
    private BigDecimal yfjsMny; // 应发计税
    private BigDecimal yfmsMny; // 应发免税
    private BigDecimal jobMny; // 岗位工资
    private BigDecimal performanceMny; // 绩效工资
    private BigDecimal workYearMny; // 司龄补贴
    private BigDecimal workTypeMny; // 职称补贴
    private BigDecimal certificateMny; // 证书补贴
    private BigDecimal travelMny; // 派驻补贴
    private BigDecimal trafficMny; // 交通补贴
    private BigDecimal mealMny; // 餐补
    private BigDecimal benefitMny; // 福利费
    private BigDecimal holidayMny; // 过节费
    private BigDecimal yearEndMny; // 年终奖
    private BigDecimal overtimeMny; // 加班费
    private BigDecimal addMny; // 补款
    private BigDecimal buttonMny; // 扣款
    private BigDecimal salaryMny; // 工资合计
    private BigDecimal yfSalaryMny; // 应发工资
    private BigDecimal yfmsSalaryMny; // 应发+免税
    private BigDecimal orgSalaryMny; // 个人本单位累计
    private BigDecimal orgsSalaryMny; // 个人所有单位累计
    private String memo; // 备注

    public Date getMonth() {
        return month;
    }

    public void setMonth(Date month) {
        this.month = month;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public Long getSbcdOrgId() {
        return sbcdOrgId;
    }

    public void setSbcdOrgId(Long sbcdOrgId) {
        this.sbcdOrgId = sbcdOrgId;
    }

    public String getSbcdOrgName() {
        return sbcdOrgName;
    }

    public void setSbcdOrgName(String sbcdOrgName) {
        this.sbcdOrgName = sbcdOrgName;
    }

    public String getSbcdOrgCode() {
        return sbcdOrgCode;
    }

    public void setSbcdOrgCode(String sbcdOrgCode) {
        this.sbcdOrgCode = sbcdOrgCode;
    }

    public BigDecimal getUnWriteOffMny() {
        return unWriteOffMny;
    }

    public void setUnWriteOffMny(BigDecimal unWriteOffMny) {
        this.unWriteOffMny = unWriteOffMny;
    }

    public BigDecimal getWriteOffMny() {
        return writeOffMny;
    }

    public void setWriteOffMny(BigDecimal writeOffMny) {
        this.writeOffMny = writeOffMny;
    }

    public BigDecimal getYfjsMny() {
        return yfjsMny;
    }

    public void setYfjsMny(BigDecimal yfjsMny) {
        this.yfjsMny = yfjsMny;
    }

    public BigDecimal getYfmsMny() {
        return yfmsMny;
    }

    public void setYfmsMny(BigDecimal yfmsMny) {
        this.yfmsMny = yfmsMny;
    }

    public BigDecimal getJobMny() {
        return jobMny;
    }

    public void setJobMny(BigDecimal jobMny) {
        this.jobMny = jobMny;
    }

    public BigDecimal getPerformanceMny() {
        return performanceMny;
    }

    public void setPerformanceMny(BigDecimal performanceMny) {
        this.performanceMny = performanceMny;
    }

    public BigDecimal getWorkYearMny() {
        return workYearMny;
    }

    public void setWorkYearMny(BigDecimal workYearMny) {
        this.workYearMny = workYearMny;
    }

    public BigDecimal getWorkTypeMny() {
        return workTypeMny;
    }

    public void setWorkTypeMny(BigDecimal workTypeMny) {
        this.workTypeMny = workTypeMny;
    }

    public BigDecimal getCertificateMny() {
        return certificateMny;
    }

    public void setCertificateMny(BigDecimal certificateMny) {
        this.certificateMny = certificateMny;
    }

    public BigDecimal getTravelMny() {
        return travelMny;
    }

    public void setTravelMny(BigDecimal travelMny) {
        this.travelMny = travelMny;
    }

    public BigDecimal getTrafficMny() {
        return trafficMny;
    }

    public void setTrafficMny(BigDecimal trafficMny) {
        this.trafficMny = trafficMny;
    }

    public BigDecimal getMealMny() {
        return mealMny;
    }

    public void setMealMny(BigDecimal mealMny) {
        this.mealMny = mealMny;
    }

    public BigDecimal getBenefitMny() {
        return benefitMny;
    }

    public void setBenefitMny(BigDecimal benefitMny) {
        this.benefitMny = benefitMny;
    }

    public BigDecimal getHolidayMny() {
        return holidayMny;
    }

    public void setHolidayMny(BigDecimal holidayMny) {
        this.holidayMny = holidayMny;
    }

    public BigDecimal getYearEndMny() {
        return yearEndMny;
    }

    public void setYearEndMny(BigDecimal yearEndMny) {
        this.yearEndMny = yearEndMny;
    }

    public BigDecimal getOvertimeMny() {
        return overtimeMny;
    }

    public void setOvertimeMny(BigDecimal overtimeMny) {
        this.overtimeMny = overtimeMny;
    }

    public BigDecimal getAddMny() {
        return addMny;
    }

    public void setAddMny(BigDecimal addMny) {
        this.addMny = addMny;
    }

    public BigDecimal getButtonMny() {
        return buttonMny;
    }

    public void setButtonMny(BigDecimal buttonMny) {
        this.buttonMny = buttonMny;
    }

    public BigDecimal getSalaryMny() {
        return salaryMny;
    }

    public void setSalaryMny(BigDecimal salaryMny) {
        this.salaryMny = salaryMny;
    }

    public BigDecimal getYfSalaryMny() {
        return yfSalaryMny;
    }

    public void setYfSalaryMny(BigDecimal yfSalaryMny) {
        this.yfSalaryMny = yfSalaryMny;
    }

    public BigDecimal getYfmsSalaryMny() {
        return yfmsSalaryMny;
    }

    public void setYfmsSalaryMny(BigDecimal yfmsSalaryMny) {
        this.yfmsSalaryMny = yfmsSalaryMny;
    }

    public BigDecimal getOrgSalaryMny() {
        return orgSalaryMny;
    }

    public void setOrgSalaryMny(BigDecimal orgSalaryMny) {
        this.orgSalaryMny = orgSalaryMny;
    }

    public BigDecimal getOrgsSalaryMny() {
        return orgsSalaryMny;
    }

    public void setOrgsSalaryMny(BigDecimal orgsSalaryMny) {
        this.orgsSalaryMny = orgsSalaryMny;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
}

==> ejc-salary-api-3.0.0-20241025.053552-55-sources.jar: com/ejianc/business/salary/vo/SourceDetailVO.java <==
package com.ejianc.business.salary.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 薪资来源
 * 
 * @author generator
 * 
 */
public class SourceDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Date month; // 月份
    private Long orgId; // 单位id
    private String orgName; // 单位名称
    private String orgCode; // 单位编码
    private Long sbcdOrgId; // 社保承担单位id
    private String sbcdOrgName; // 社保承担单位名称
    private String sbcdOrgCode; // 社保承担单位编码

    private BigDecimal unWriteOffMny; // 截止当前未核销金额
    private BigDecimal writeOffMny; // 本次核销金额
    private BigDecimal yfjsMny; // 应发计税
    private BigDecimal yfmsMny; // 应发免税
    private BigDecimal jobMny; // 岗位工资
    private BigDecimal performanceMny; // 绩效工资
    private BigDecimal workYearMny; // 司龄补贴
    private BigDecimal workTypeMny; // 职称补贴
    private BigDecimal certificateMny; // 证书补贴
    private BigDecimal travelMny; // 派驻补贴
    private BigDecimal trafficMny; // 交通补贴
    private BigDecimal mealMny; // 餐补
    private BigDecimal benefitMny; // 福利费
    private BigDecimal holidayMny; // 过节费
    private BigDecimal yearEndMny; // 年终奖
    private BigDecimal overtimeMny; // 加班费
    private BigDecimal addMny; // 补款
    private BigDecimal buttonMny; // 扣款
    private BigDecimal salaryMny; // 工资合计
    private BigDecimal yfSalaryMny; // 应发工资
    private BigDecimal yfmsSalaryMny; // 应发+免税
    private BigDecimal orgSalaryMny; // 个人本单位累计
    private BigDecimal orgsSalaryMny; // 个人所有单位累计
    private BigDecimal taxYfmsMny; // 个税计算、工资单应发免税
    private Long taxBillDetailId; // 个税计算子表id
    private String memo; // 备注

    public Date getMonth() {
        return month;
    }

    public void setMonth(Date month) {
        this.month = month;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public Long getSbcdOrgId() {
        return sbcdOrgId;
    }

    public void setSbcdOrgId(Long sbcdOrgId) {
        this.sbcdOrgId = sbcdOrgId;
    }

    public String getSbcdOrgName() {
        return sbcdOrgName;
    }

    public void setSbcdOrgName(String sbcdOrgName) {
        this.sbcdOrgName = sbcdOrgName;
    }

    public String getSbcdOrgCode() {
        return sbcdOrgCode;
    }

    public void setSbcdOrgCode(String sbcdOrgCode) {
        this.sbcdOrgCode = sbcdOrgCode;
    }

    public BigDecimal getUnWriteOffMny() {
        return unWriteOffMny;
    }

    public void setUnWriteOffMny(BigDecimal unWriteOffMny) {
        this.unWriteOffMny = unWriteOffMny;
    }

    public BigDecimal getWriteOffMny() {
        return writeOffMny;
    }

    public void setWriteOffMny(BigDecimal writeOffMny) {
        this.writeOffMny = writeOffMny;
    }

    public BigDecimal getYfjsMny() {
        return yfjsMny;
    }

    public void setYfjsMny(BigDecimal yfjsMny) {
        this.yfjsMny = yfjsMny;
    }

    public BigDecimal getYfmsMny() {
        return yfmsMny;
    }

    public void setYfmsMny(BigDecimal yfmsMny) {
        this.yfmsMny = yfmsMny;
    }

    public BigDecimal getJobMny() {
        return jobMny;
    }

    public void setJobMny(BigDecimal jobMny) {
        this.jobMny = jobMny;
    }

    public BigDecimal getPerformanceMny() {
        return performanceMny;
    }

    public void setPerformanceMny(BigDecimal performanceMny) {
        this.performanceMny = performanceMny;
    }

    public BigDecimal getWorkYearMny() {
        return workYearMny;
    }

    public void setWorkYearMny(BigDecimal workYearMny) {
        this.workYearMny = workYearMny;
    }

    public BigDecimal getWorkTypeMny() {
        return workTypeMny;
    }

    public void setWorkTypeMny(BigDecimal workTypeMny) {
        this.workTypeMny = workTypeMny;
    }

    public BigDecimal getCertificateMny() {
        return certificateMny;
    }

    public void setCertificateMny(BigDecimal certificateMny) {
        this.certificateMny = certificateMny;
    }

    public BigDecimal getTravelMny() {
        return travelMny;
    }

    public void setTravelMny(BigDecimal travelMny) {
        this.travelMny = travelMny;
    }

    public BigDecimal getTrafficMny() {
        return trafficMny;
    }

    public void setTrafficMny(BigDecimal trafficMny) {
        this.trafficMny = trafficMny;
    }

    public BigDecimal getMealMny() {
        return mealMny;
    }

    public void setMealMny(BigDecimal mealMny) {
        this.mealMny = mealMny;
    }

    public BigDecimal getBenefitMny() {
        return benefitMny;
    }

    public void setBenefitMny(BigDecimal benefitMny) {
        this.benefitMny = benefitMny;
    }

    public BigDecimal getHolidayMny() {
        return holidayMny;
    }

    public void setHolidayMny(BigDecimal holidayMny) {
        this.holidayMny = holidayMny;
    }

    public BigDecimal getYearEndMny() {
        return yearEndMny;
    }

    public void setYearEndMny(BigDecimal yearEndMny) {
        this.yearEndMny = yearEndMny;
    }

    public BigDecimal getOvertimeMny() {
        return overtimeMny;
    }

    public void setOvertimeMny(BigDecimal overtimeMny) {
        this.overtimeMny = overtimeMny;
    }

    public BigDecimal getAddMny() {
        return addMny;
    }

    public void setAddMny(BigDecimal addMny) {
        this.addMny = addMny;
    }

    public BigDecimal getButtonMny() {
        return buttonMny;
    }

    public void setButtonMny(BigDecimal buttonMny) {
        this.buttonMny = buttonMny;
    }

    public BigDecimal getSalaryMny() {
        return salaryMny;
    }

    public void setSalaryMny(BigDecimal salaryMny) {
        this.salaryMny = salaryMny;
    }

    public BigDecimal getYfSalaryMny() {
        return yfSalaryMny;
    }

    public void setYfSalaryMny(BigDecimal yfSalaryMny) {
        this.yfSalaryMny = yfSalaryMny;
    }

    public BigDecimal getYfmsSalaryMny() {
        return yfmsSalaryMny;
    }

    public void setYfmsSalaryMny(BigDecimal yfmsSalaryMny) {
        this.yfmsSalaryMny = yfmsSalaryMny;
    }

    public BigDecimal getOrgSalaryMny() {
        return orgSalaryMny;
    }

    public void setOrgSalaryMny(BigDecimal orgSalaryMny) {
        this.orgSalaryMny = orgSalaryMny;
    }

    public BigDecimal getOrgsSalaryMny() {
        return orgsSalaryMny;
    }

    public void setOrgsSalaryMny(BigDecimal orgsSalaryMny) {
        this.orgsSalaryMny = orgsSalaryMny;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public BigDecimal getTaxYfmsMny() {
        return taxYfmsMny;
    }

    public void setTaxYfmsMny(BigDecimal taxYfmsMny) {
        this.taxYfmsMny = taxYfmsMny;
    }

    public Long getTaxBillDetailId() {
        return taxBillDetailId;
    }

    public void setTaxBillDetailId(Long taxBillDetailId) {
        this.taxBillDetailId = taxBillDetailId;
    }
}
